#
# spec file for package gnome-tweaks
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2011 Luis Medinas, Lisbon, Portugal.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-tweaks
Version:        45.0
Release:        1.1
Summary:        A tool to customize advanced GNOME 3 options
License:        CC0-1.0 AND GPL-3.0-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Apps/Tweaks
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  fdupes
# GI is needed to have typelib() Requires
BuildRequires:  gobject-introspection
# Hicolor is Needed for directory ownership
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libhandy-1)
Requires:       gnome-settings-daemon
# Gsettings Schemas are needed from: gnome-shell, g-d-s and mutter
Requires:       gnome-shell >= 3.24
Requires:       gsettings-desktop-schemas >= 3.27.90
Requires:       mutter
Requires:       python3-gobject >= 3.10
Requires:       python3-gobject-Gdk
Requires:       python3-xml
# Gnome-tweak-tool was renamed to gnome-tweaks in 3.27.4
Provides:       gnome-tweak-tool = %{version}
Obsoletes:      gnome-tweak-tool < 3.27.4
Obsoletes:      gnome-tweak-tool-lang < 3.27.4
BuildArch:      noarch

%description
GNOME Tweak Tool is an application for changing the advanced settings
of GNOME 3.

%lang_package

%prep
%autosetup -p1
# Tiny tweak to shut up rpmlint
sed -i 's:Pantheon:X-Pantheon:g' */org.gnome.tweaks.desktop.in
# Tweak to fix python env
sed -i "s|#!%{_bindir}/env python3|#!%{_bindir}/python3|g" gnome-tweak*

%build
%meson
%meson_build

%install
%meson_install
# FIXME Drop traces of buildroot
rm -rf %{buildroot}/%{python3_sitelib}/gtweak/__pycache__/*.pyc
rm -rf %{buildroot}/%{python3_sitelib}/gtweak/tweaks/__pycache__/*.pyc
%fdupes %{buildroot}%{_datadir}/gnome-tweaks/
%fdupes %{buildroot}%{python_sitelib}
%find_lang %{name} %{?no_lang_C}

%files
%license LICENSES/*
%doc AUTHORS NEWS README.md
%{_bindir}/%{name}
%{python3_sitelib}/gtweak/
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.gnome.tweaks.appdata.xml
%{_datadir}/applications/org.gnome.tweaks.desktop
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/apps/org.gnome.tweak*
%{_datadir}/glib-2.0/schemas/org.gnome.tweaks.gschema.xml

%files lang -f %{name}.lang

%changelog
* Sat Sep 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + This release removes several features now found in GNOME
    Settings. There are also some small interface refreshments in
    preparation for the GTK4 upgrade. More significantly, the core
    interface has been refactored to use layout files.
  + Updated translations.
- Switch compression to zst both in service and tarball produced.
* Wed Mar 22 2023 bjorn.lie@gmail.com
- Update to version 42.beta+60:
  + Removed libsoup mention.
  + data: Remove extension mentions.
  + appdata: Remove GNOME 3 mention.
  + Remove deprecated option for separate Lock screen wallpaper.
  + Updated translations.
- Switch to git checkout via source service, explicit commit id.
* Sat Mar  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + GNOME Tweaks 42 focuses on removing tweaks which are now
    duplicated by Settings. Additionally, Tweaks 42 marks the GTK
    theme tweak as "Legacy". In GNOME 42, the "Legacy Applications"
    setting will only apply to some GTK3 apps and a limited set of
    GTK4 apps. Most core GNOME apps will instead respect the user's
    dark and light mode preference via libadwaita. Users interested
    in theming can continue to do so using more advanced options
    such as the GTK_THEME environment variable.
- Add pkgconfig(libhandy-1) BuildRequires: New dependency.
* Sat Mar  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.10:
  + Fix for the broken GNOME Extensions link.
  + Fix build with meson 0.60 and newer.
  + Updated translations.
- Drop 86.patch: Fixed upstream.
* Tue Feb  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 86.patch: Fix build with meson 0.60.0 and newer.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Apr 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Fix "Fails to recognize GNOME Shell 40.rc running"
  + Updated translations.
- Drop 70.patch: fixed upstream.
* Fri Mar 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add 70.patch: gshellwrapper: Fails to find Shell when its version
  is not from numbers only.
* Mon Feb 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 40.beta:
  + GNOME Tweaks 40 brings several bug fixes, support for GNOME 40
    settings changes, and removes GNOME Shell Extensions support.
    Extensions support can now be found in the GNOME Extensions
    app.
  + Port to libhandy 1.0.
  + Show the back button when leaflet is folded.
  + Update to new gsettings-desktop-schemas location.
  + Drop unused extensions support.
  + Use Gtk.HeaderBar instead of Handy.HeaderBar.
  + Add notice for Extensions removal.
- Remove upstreamed patches:
  + 77dde7477922f645946bfc64b1b25aeed2b01919.patch
  + gnome-tweaks-port-libhandy-1.patch
  + gnome-tweaks-port-new-schema-loc.patch
* Tue Jan 19 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add 77dde7477922f645946bfc64b1b25aeed2b01919.patch -- Update
  Norwegian bokmål translation.
* Tue Jan 19 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add gnome-tweaks-port-new-schema-loc.patch: font: Update font
  aa/hinting to new gsettings-desktop-schemas location: Support
  new gnome-40-alpha changed location of schemas.
* Fri Dec 11 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Fix default window sizing and requests.
  + Updated translations.
- Drop gnome-tweaks-fix-titlebar-buttons-left.patch: Fixed
  upstream, though in a different way than the patch we had.
* Fri Nov 27 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add gnome-tweaks-port-libhandy-1.patch: Port to using new handy.
* Wed Oct 28 2020 Alynx Zhou <alynx.zhou@suse.com>
- Updated gnome-tweaks-fix-titlebar-buttons-left.patch: Upstream
  has new commit to fix titlebar layout when buttons are placed
  left, so update the patch. (glgo#GNOME/gnome-tweaks!63)
* Thu Aug  6 2020 Alynx Zhou <alynx.zhou@suse.com>
- Added gnome-tweaks-fix-titlebar-buttons-left.patch: GNOME Tweaks
  titlebar starts flickering when setting button placement to left,
  this patch fixes it. (bsc#1162080, glgo#GNOME/gnome-tweaks#245)
* Fri Sep 27 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Update gsettings schema for the Activities Overview Hot Corner.
  + Fix an assertion with the new libhandy integration.
  + Updated translations.
* Sun Sep  1 2019 mgorse@suse.com
- Update to version 3.33.90:
  + Use libhandy so the app displays better on narrower screens.
  + Drop obsolete Application Menu tweak.
  + Update GTK+ to GTK.
  + Adapt to GNOME 3.33/3.34 gsettings schema changes.
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Wed Feb 20 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + App icon refresh.
  + Enable F10 hotkey for app menu.
  + Fix crash when changing any option in Additional Layout Options
    after closing the dialog at least once.
  + Updated translations.
* Thu Jan  3 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Fix running Tweaks outside of GNOME Shell.
  + Update menus for GNOME 3.32 recommendations.
  + Adjust Application ID to match the .desktop.
  + Updated translations.
- Changes from version 3.31.1:
  + Redesign the app icon.
  + Mention in README that sound-theme-freedesktop is required.
  + Code cleanup for pycodestyle compliance.
  + Updated translations.
* Mon Dec 10 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + Fix running Tweaks outside of GNOME Shell.
  + Mention in README that sound-theme-freedesktop is required.
  + Updated translations.
* Thu Sep 27 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Fix visual glitch by making rows non-activatable by default.
  + Use dim-label for Shell extension descriptions instead of
    hardcoded color.
  + Updated translations.
* Fri Sep  7 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Show Over-Amplification in the Pop session.
  + Updated translations.
- Remove lang package from recommended packages as it already
  supplements main package.
* Tue Aug 28 2018 bjorn.lie@gmail.com
- Update to version 3.29.92:
  + Fix too small window when unmaxizing.
  + Move General panel to the top of the sidebar.
  + Minor adjustments to order in top bar panel.
  + Don't show Over-Amplification when running the Ubuntu or Pop
    sessions.
  + Updated translations.
* Mon Aug 13 2018 bjorn.lie@gmail.com
- Update to version 3.29.91.1:
  + Trivial URL updates.
  + Updated translations.
* Tue Aug  7 2018 bjorn.lie@gmail.com
- Update to version 3.29.90.1:
  + Add Weekday on/off switch for the clock in the top bar.
- Changes from version 3.29.90:
  + Move Animations, Power, and Sound to new General panel.
  + Add Sound theme chooser to Appearance panel.
  + Extend font labels for clarify ("Interface text" instead of
    "Interface", etc.).
  + Rename "Sloppy" window focus to "Focus on Hover".
  + Drop custom handler and use new glib per-session overrides.
  + Updated translations.
* Tue May 22 2018 luc14n0@linuxmail.org
- Update to version 3.29.2:
  + Add Center New Windows and Edge Tiling tweaks.
  + Split Window Titlebars section to separate panel.
  + font: Rename Window Title to Legacy Window Title
    since it doesn't affect client-side decorations.
- Add gnome-settings-daemon, gsettings-desktop-schemas and mutter
  BuildRequires: some missing requirements. And hicolor-icon-theme
  BuildRequires for directory ownership.
- Drop gsettings-desktop-schemas, gtk+-3.0 and pygobject-3.0
  pkgconfig BuildRequirement: they are no longer required nor used.
- Apend CC0-1.0 to License tag to comply with due software
  licensing.
* Sun Apr  8 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Show Activites Overview Hot Corner switch if the gnome-shell
    gsettings schema is installed.
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Wed Mar  7 2018 bjorn.lie@gmail.com
- Update to version 3.27.92:
  + Install the Desktop panel again.
  + Only show the Desktop panel if Nautilus < 3.27 is installed.
  + Fix a crash when schemas are missing (like the Nautilus
    schemas).
  + Add provides tag for old AppStream ID.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Feb 10 2018 bjorn.lie@gmail.com
- Drop obsolete hicolor-icon-theme and update-desktop-files
  BuildRequires, and the suse_update_desktop_file macro, no longer
  needed.
- Minor spec cleanup.
* Wed Feb  7 2018 luc14n0@linuxmail.org
- Update to version 3.27.90.2:
  + Install new sound panel. Note that the sound panel will only
    show if you have gsettings-desktop-schemas >= 3.27.90
    installed.
  + Rename a few more things to GNOME Tweaks.
- Update Url tag to https://wiki.gnome.org/Apps/Tweaks: newest
  Tweaks' web page.
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Redesign 'Mouse Click Emulation' section. Note that GNOME 3.28
    switches the default to 'Fingers'. Previously, it was 'Area'
    for most laptops.
  + Move Background & Lock Screen tweaks from Desktop to
    Appearance.
  + Don't install the Desktop panel.
- Changes from version 3.27.4:
  + This release renames the source tarball, binary, icons,
    .desktop and AppStream metadata to GNOME Tweaks. The
    user visible name was already changed for 3.26.
  + Don't show duplicate cursor theme names.
  + Add Sound panel with Over-Amplification tweak. This tweak (and
    panel) will only appear if run with gsettings-desktop-schemas
    3.27.2+.
  + Support XDG_DATA_DIRS for themes and icons.
  + Support XDG_DATA_DIRS for gsettings schemas.
- Rename package to gnome-tweaks, providing and obsoleting
  gnome-tweak-tool and gnome-tweak-tool-lang (to ease upgrade).
* Fri Dec 29 2017 zaitor@opensuse.org
- Drop obsolete and unused pkgconfig(gconf-2.0) BuildRequires:
  Dropped upstream years ago.
* Fri Dec 15 2017 fezhang@suse.com
- Update to version 3.27.3:
  + Updated translations.
* Fri Dec 15 2017 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + Remove Global Dark Theme tweak. The option will be turned off
    when the Applications theme is changed.
  + Stop requiring a GTK2 theme for Applications theme switcher.
  + Offer HighContrastInverse theme.
  + Don't show duplicate theme names.
  + Update copyright headers for REUSE Initiative Best Practices.
  + Update AppStream metadata
  + Updated translations.
* Fri Dec 15 2017 luc14n0@linuxmail.org
- Update Url to https://wiki.gnome.org/Apps/GnomeTweakTool: current
  GNOME Tweak Tool's web page.
* Thu Dec 14 2017 zaitor@opensuse.org
- Update to version 3.26.4:
  + Stop requiring a GTK2 theme for Applications theme switcher.
  + Offer HighContrastInverse theme.
  + Don't show duplicate theme names.
  + Updated translations.
- Add sed hack to replace the "/usr/bin/env python3" hashbang with
  "/usr/bin/python3" in the scripts to be installed.
* Thu Nov  2 2017 fezhang@suse.com
- Update to version 3.26.3:
  + Updated translations.
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.2.1:
  + Don't offer emoji support in search boxes.
  + Updated translations.
* Thu Sep 21 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + New bugfix release:
  - Fix enabling and disabling GNOME Shell extensions.
  - Fix Workspace tweaks in GNOME Shell and "modes".
  - Hide Workspaces panel if GNOME Shell isn't running.
  - Add "Activities Overview Hot Corner" tweak. This is disabled
    by default because it requires a patch from bgo#688320 that
    hasn't been committed yet.
  + Updated translations.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Wed Sep  6 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + Fix linking to GNOME Software from Extensions page.
  + Note that gnome-shell schemas >= 3.24 are required.
  + Updated translations.
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Don't add appmenu to windows buttons if it's already there.
  + Prompt to log out when changing Application Menu setting.
  + Updated translations.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.25.90.1:
  + Fix vertical scrollbar placement.
  + Restore redesigned Window Focus Mode listbox.
- Changes from version 3.25.90:
  + Remove Power Button setting; this feature is now in
    gnome-control-center 3.25.90+.
  + Don't show HiDPI setting; use gnome-control-center 3.25.90+
    instead.
  + Revert Focus Mode list box to 3.24 combobox to eliminate
    vertical scrolling.
  + Rename /usr/bin/gnome-tweaks back to /usr/bin/gnome-tweak-tool.
  + Add '--version' option to /usr/bin/gnome-tweak-tool.
  + Make notification string translatable.
  + Updated translations.
* Wed Jul 19 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Rename app to GNOME Tweaks.
  + Rename binary to gnome-tweaks.
  + Only allows numbers in Hi-DPI entry box.
  + Updated translations.
- Changes from version 3.25.3:
  + Move Typing panel to Additional Layout Options dialog in
    Keyboard & Mouse.
  + Move Compose Key setting to Keyboard & Mouse dialog.
  + Convert some settings to ListBoxes.
  + Several other UI tweaks to match Design Team mockup.
  + Only show Top Bar page and Overview Shortcut if GNOME Shell is
    running.
  + Enable 'appmenu' window button when disabling App Menu.
  + Use Ubuntu sort order for Left placement of window buttons.
  + Fix "blank slate" for Extensions page.
  + Drop build-time checks for run-time dependencies.
  + Distributors, please see README for run-time dependencies
  + Consistently use /usr/bin/env python3 shebangs.
  + Rewrite post-install script in Python.
  + Handle SIGINT (Ctrl+C).
- Drop post(un) handling of icon_theme_cache_post(un), no longer
  needed as we have file-triggers taking care of this for us now.
- Tweak .desktop file with sed replacement to quiet rpmlint.
* Mon Jun 12 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Add "Battery Percentage" tweak.
  + Add "Disable While Typing" tweak.
  + Add Left/Right Placement tweak for window buttons.
  + Update About to show Tweak Tool and GTK+ versions.
  + Add "blank slate" for Extensions page.
  + Remove support for installing and uninstalling extensions since
    GNOME Software handles this since 3.22.
  + Other UI tweaks to Extensions page.
  + Many UI tweaks suggested by Allan Day.
  + Misc code cleanup.
  + Use Unicode in translatable strings.
  + Create config directories as necessary.
  + Install appstream metadata to /usr/share/metainfo/.
  + Switch from python2 to python3.
  + Switch from autotools to meson.
  + Drop intltool dependency.
  + Updated translations.
- Drop intltool BuildRequires: Following upstream changes.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Replace python-gobject, python-gobject-Gdk and python-xml with
  python3-gobject, python3-gobject-Gdk and python3-xml Requires
  following upstreams port to python3.
- Drop %%py_requires: no longer needed with python3.
* Mon Jun 12 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Fix search.
  + Fix running Tweak Tool if GNOME Shell is not running.
  + Only show Top Bar panel if GNOME Shell is running.
  + Create config directories as necessary.
  + Explicitly use python2 shebang.
  + Handle SIGINT.
  + Require gsettings-desktop-schemas 3.23.3+ and pygobject 3.10+.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Add a gnome-shell extensions "kill switch".
  + Make Gtk/EnablePrimaryPaste also configurable on wayland.
  + Updated translations.
* Tue Sep 20 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Add XKB options that are not in the 3.22 Keyboard panel.
  + Updated translations.
* Mon Sep  5 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Add a mouse acceleration profile tweak.
  + Add a proper title to the main window.
  + Use the new org.gnome.desktop.calendar schema.
  + Fix screenshot link in appdata.
  + Updated translations.
* Mon Aug  8 2016 fezhang@suse.com
- Drop gnome-tweak-tool-bnc898328-remove-lid-action-entries.patch
  (bsc#898328). Original problem fixed upstream and lid action is
  back.
* Mon May 23 2016 cxiong@suse.com
- Update to GNOME 3.20.2 FATE#318572
- Dropped bnc951346-add-sle-classic-schema-overrides-check.patch
  Not needed any more with 3.20-based SLE Classic.
* Tue May  3 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Rebase gnome-tweak-tool-bnc898328-remove-lid-action-entries.patch
* Fri Apr 22 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Support versioned Gtk3 themes.
  + Support multiple selection XKB options.
  + Updated translations.
* Tue Apr 19 2016 dimstar@opensuse.org
- Require python-gobject-Gdk: pygobject was further split in order
  to be able to install it without X-dependencies. As g-t-t is
  a GUI applicartion, the dependency on the X-stack is no issue
  (boo#976069).
* Wed Mar 23 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Reduce the amount of logging we do by default.
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Update the AppData file to 0.7+ and add some missing data.
  + Updated translations.
* Mon Jan 18 2016 dimstar@opensuse.org
- Update to version 3.19.1:
  + Restore ‘Power button action’ setting.
  + Use selected font on font selector buttons.
  + Drop dependency on SoupGNOME.
  + Updated translations.
* Tue Dec  1 2015 cxiong@suse.com
- Add bnc951346-add-sle-classic-schema-overrides-check.patch
  (bnc951346). Add sle-classic to the manual overrides checking, so
  configuration through tweak-tools would behave consistently.
* Wed Nov 11 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Fixed a crash with some values in the
    org.gnome.desktop.wm.preferences button-layout key.
  + Avoid pygobject unversioned import warnings.
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Avoid GSettings aborting when missing classic overrides schema.
  + Startup: Honor disabled user autostart files.
  + Updated translations.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Add a click method tweak for touchpads.
  + Updated translations.
- Add missing runtime Requires: python-xml.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Several usability improvements in the startup tab and
    application chooser.
  + Provide a symbolic variant of the app icon.
  + Add a way to inhibit systemd's default behavior on lid close.
  + Switch to expanders and radio buttons instead of combo boxes
    for the XKB options.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Several usability improvements in the startup tab and
    application chooser.
  + Provide a symbolic variant of the app icon.
  + Add a way to inhibit systemd's default behavior on lid close.
  + Updated translations.
* Thu Apr 16 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Removed a couple of XKB options that aren't supported in GNOME.
  + Updated translations.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Add "Enable Animations" entry in Appearance group.
  + Make tweak-group and tweak have a transparent background.
  + Use the proper gsetting for "Automatically Raise Windows".
  + Maximize the window on small screens.
  + Take other buttons into account when changing button layout.
  + Updated translations.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Use the correct default for icon-themes.
  + interface: Remove WindowTheme tweak.
  + Add a confirmation message when changing HiDPI.
  + Change Right/Left super shortcut name.
  + ShellExtension: fix extension prefs button style.
  + Automatically search when unhandled keyboard input is detected.
  + Implemented search functionality for startup applications.
  + Updated translations.
* Wed Dec  3 2014 fezhang@suse.com
- Add gnome-tweak-tool-bnc898328-remove-lid-action-entries.patch
  (bnc#898328). Remove the lid actions from GUI since they are now
  handled by systemd.
* Fri Nov 14 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + startup:
  - Fix check for running executables.
  - Sort application selection list alphabetically.
  + tweakview: Update decorations on settings changes.
  + windows: Stop overriding the Gtk/DecorationLayout xsetting.
  + Remove the use of deprecated properties.
  + Make the window a bit taller.
  + GTK+ required version bump to 3.12.
  + Updated translations.
* Sun Oct  5 2014 zaitor@opensuse.org
- Move .desktopfile from X-GNOME-SystemSettings to
  X-GNOME-PersonalSettings, since the only values one can change is
  for active user. Having it under System gives the impression that
  changes are systemwide.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Fix missed function rename, deprecation warnings.
  + Fix some more positional arguments.
  + Updated translations.
* Wed Sep 17 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Disable the menubar.
  + Fix KeyError when extensions with no version are installed.
  + Stop using positional arguments with the GObject constructor
    (bgo#725926).
  + Fix a string that wasn't translated.
  + Updated translations.
* Fri Jun 13 2014 fezhang@suse.com
- Add category X-GNOME-SystemSettings to gnome-tweak-tool.desktop
  so that gnome-control-center can recongnize and show it
  (bnc#866235).
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Add Gdk/WindowScalingFactor tweak.
  + Remove non-functional help menu.
  + Support CSD windows with header bars.
  + Support changing shell overlay keyboard shorcut.
  + Support changing shell lock screen background.
  + Fix CSD header bar.
  + Fix background color of startup apps tab.
  + Fix icon theme detection.
  + Add another digit for font size tweaks.
  + Allow localized searches.
  + More robust startup application handling.
  + Updated translations.
* Tue Nov 12 2013 dimstar@opensuse.org
- Update to version 3.10.1 (bnc#849913):
  + Work around PyGObject bug which caused crashes at startup.
  + Fix detection of themes (bgo#710275).
  + Fix shell extension update checks for stable X.0 releases.
  + Fix startup tweaks for applications missing icons (bgo#708900).
  + Allow localized searches.
  + Fix shell extension error reporting (bgo#711490).
- Drop gnome-tweak-tool-threading-crashes.patch: fixed upstream.
* Tue Oct 22 2013 dimstar@opensuse.org
- Add gnome-tweak-tool-threading-crashes.patch: Fix crashes due to
  threading locks (bnc#846754, bgo#710530).
* Wed Sep 25 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Fix appdata file.
  + Updated translations.
* Thu Sep 19 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Fix CSD decorations.
  + Ship an appdata file.
  + Make titlebar buttons match mockups (more).
  + Startup applications tidy ups.
* Wed Sep  4 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Make titlebar buttons match mockups.
  + Make workspace creation match mockups.
  + Improve search results for gsettings tweaks.
  + Updated translations.
* Thu Aug 22 2013 dimstar@opensuse.org
- Update to version 3.9.90.1:
  + Dont crash when failing to load desktop files.
  + Require GTK 3.9 for ListBox.
- Add pkgconfig(gtk+-3.0) BuildRequires: new verified dependency.
* Thu Aug 22 2013 zaitor@opensuse.org
- Update to version 3.9.90:
  + Complete UI redesign based on GNOME3.
  + Allow updating extensions from inside tweak tool (bgo#696948).
  + Show text in tooltip when label is ellipsized (bgo#704149).
  + Reluctantly make window resizable (bgo#704149).
  + Specialized ui for certain tweaks.
  + Tweaks can depend on other tweaks being enabled.
  + Add XSettings related tweaks (middle mouse paste, appplication
    menu).
  + Add startup application management.
  + Offer to logout user when tweaks require the session restarted.
  + Better tweak names and descriptions (manage our own
    translations instead of getting all from gsettings).
* Thu Jul 18 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Use extension specific paths to find pref.js (bgo#697685).
  + Dont look in ~/.themes for metacity themes (bgo#693350).
  + Add groups only if they have tweaks (bgo#699572).
  + Work with gnome-shell classic mode (bgo#701760).
* Mon Apr  8 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Fix manual extension installation.
  + Add tweak for window raise-on-click (bgo#696890)
  + Don't crash if gnome-shell is not running/installed
    (bgo#696683)
  + List extensions alphabetically (bgo#695170).
  + Allow uninstalling / deleting extensions (bgo#695983).
  + Show all XKB options except the ones in control center
    (bgo#691381)
  + Fix g-t-t running in classic mode (bgo#694808).
  + Updated translations.
* Fri Mar 15 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Find a theme from XDG base directory spec (bgo#688028).
  + Add keywords to the .desktop file (bgo#687949).
  + Honor different gnome-shell modes on relevant tweaks
    (bgo#689358).
  + Add desktop background options (bgo#689299).
  + Add Pantheon to OnlyShowIn (bgo#684097).
  + Show the XKB option group description (bgo#678171).
  + Use the new laptop lid policy in xrandr (bgo#688814).
  + Several code clean ups.
  + Updated translations.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Add a Mouse group with the locate-pointer key (bgo#685620)
  + Add tweak for resize-with-right-button on Windows group
    (bgo#678648)
  + Add tweak for mouse-button-modifier on Windows group
    (bgo#678648)
  + Updated translations.
* Thu Oct  4 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Can configure extension preferences
  + Support input sources (bgo#684712)
  + Support typing options (bgo#678171)
  + Support power-button action
  + Many translation improvements (bgo#683630).
- Drop gnome-tweak-tool-pwr-button.patch: fixed upstream.
* Mon Aug 13 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Now appear as "Tweak Tool" in Activities (bgo#678778)
  + Fix incompatibility with new gnome-shell extensions (bgo678778)
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Update icon (bgo#649359)
  + Fix appearance of tweaks to no longer have a white background
  + Remove welcome image and start with a tweakgroup selected by
    default
  + Add link to extensions.gnome.org
- Changes from version 3.5.0:
  + Work with new gnome-shell DBus interface.
- Rebase gnome-tweak-tool-pwr-button.patch.
- Add hicolor-icon-theme BuildRequires and icon_theme_cache_*
  macros in post/postun.
* Wed Jul 18 2012 dimstar@opensuse.org
- Add gnome-tweak-tool-pwr-button.patch: Allow to configure what
  action should be performed when pressing the power button (acpi)
  (bnc#770048).
- Drop xz BuildRequires as it now comes for free in the build
  system.
* Wed May 16 2012 dimstar@opensuse.org
- Update to version 3.4.0.1:
  + Fix broken pkg-config check.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Fix user-theme shell extension support (bgo#675106)
  + Support workspaces only on primary
  + Support static workspaces
  + Add nautilus always-use-location-entry
  + Change widget for text-scaling-factor to SpinButton
    (bgo#650660)
  + Dont crash on missing schemas (bgo#647132)
  + Updated translations.
* Mon Jan 16 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Adapt to Metacity/Mutter/Shell ported to GSettings
  + Adapt to GNOME Shell 3.4 DBus interface
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Sun Nov 20 2011 dimstar@opensuse.org
- Update to version 3.2.2:
  + Dont die on malformed schemas
  + Updated translations.
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Ellipsize long strings; this should fix window size issues.
  + Updated translations.
* Wed Sep 28 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Adopt GNOME version numbering
  + Rename some tweak groups, File Manager -> Desktop, etc
  + Fix build against PyGObject-3
  + Improve search results
  + Support GNOME Shell 3.2 extensions
- Change pkgconfig(pygobject-2.0) BuildRequires to
  pkgconfig(pygobject-3.0), following upstream change.
- Add python-gobject Requires as this python application obviously
  needs it.
* Fri Aug 19 2011 dimstar@opensuse.org
- Update to version 3.1.0:
  + Change tweakgroup architecture: tweaks in different files can
    appear in the same categories now.
  + Tweaks can now override summary/description usually obtained
    from gconf/gsettings
  + Move window border theme to interfaces
  + Mark many strings as translatable.
  + Now appears as 'Advanced Settings' in GNOME shell search
  + Add a -v,--verbose option that prints changed settings
  + Add a -d,--debug option
  + Add Unity to OnlyShowIn
* Wed Jun 22 2011 dimstar@opensuse.org
- Update to version 3.0.5:
  + More autostart desktop file fixes. Try harder to autostart
    nautilus when tweaking desktop handling.
  + Appearance improvements (theme install, sorted combo boxes)
  + Tweak window focus mode (focus follows mouse)
  + Tweak desktop item visibility with more control (show trash,
    show computer etc.)
  + Dont offer to restart shell multiple times when enabling
    extensions.
* Fri Jun  3 2011 dimstar@opensuse.org
- Add gobject-introspection BuildRequires to automatically get
  typelib()-style Requires.
- Drop libgtk-3-0 and gconf2 Requires. They are now added as
  typelib()-style Requires
* Sun May 22 2011 dimstar@opensuse.org
- Update to version 3.0.4:
  + bgo#648751: Support system wide themes
  + bgo#649687: Fix duplicate themes
  + A theming specification for shell themes has been developed and
    agreed upon by a number of theme authors. If installing a theme
    matching this specification, show the appropriate name.
  + Support management of Shell extensions (in home directory)
* Thu Apr 28 2011 fcrozat@novell.com
- Update to version 3.0.3:
  + bgo#648087: autostart nautilus at login if it is configured to
    show desktop icons.
  + bgo#648735: improved robustness for missing theme/icon
    directories.
  + Fix shell theme installation for themes found in the wild.
  + Improve shell theme selection.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.2:
  + Really tweak window theme - both the fallback and the shell
    metacity/mutter theme.
  + Fix attribution of data/welcome.png
- Changes from version 3.0.1:
  + Fix localization
  + Tweak window theme
  + Tweak week date in calendar
  + Tweak cursor themes
  + Support user installed themes in $HOME
  + Remove org.gnome.desktop.background draw-backgroud tweak, it
    should never be false
- Drop gnome-tweak-tool-3.0.0-fix-localization.patch: fixed
  usptream.
- Remove now unneeded calls to autoreconf and intltoolize.
* Tue Apr 26 2011 vuntz@opensuse.org
- Clean packaging for inclusion in Factory.
* Mon Apr  4 2011 lmedinas@opensuse.org
- Initial import based on spec by Michel Salim
  <salimma@fedoraproject.org>, for version 3.0.0.
- Add gnome-tweak-tool-3.0.0-fix-localization.patch: from upstream,
  fix localization issues.
